#[non_exhaustive]pub enum Request<'a> {
Destroy,
Import {
handle: String,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Destroy
destroy the xdg_importer object
Notify the compositor that the xdg_importer object will no longer be used.
This is a destructor, once sent this object cannot be used any longer.
Import
import a surface
The import request imports a surface from any client given a handle retrieved by exporting said surface using xdg_exporter.export. When called, a new xdg_imported object will be created. This new object represents the imported surface, and the importing client can manipulate its relationship using it. See xdg_imported for details.
Implementations